---
name: Question
about: Go to StackOverflow and use #pybliometrics
title: ''
labels: ''
assignees: ''

---

Please ask your question (e.g. "How do I do xyz?", "Can pybliometrics do abc"?) on StackOverflow.com, but only if it hasn't been answered yet.

Tag your question with pybliometrics.  New questions arrive directly in my inbox.
